..
    This file is part of Invenio.
    Copyright (C) 2015 CERN.

    Invenio is free software; you can redistribute it
    and/or modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.

    Invenio is distributed in the hope that it will be
    useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Invenio; if not, write to the
    Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
    MA 02111-1307, USA.

    In applying this license, CERN does not
    waive the privileges and immunities granted to it by virtue of its status
    as an Intergovernmental Organization or submit itself to any jurisdiction.

Authors
=======

Invenio-Records is a metadata storage module.

- Adrian Pawel Baran <adrian.pawel.baran@cern.ch>
- Adrian-Tudor Panescu <adrian.tudor.panescu@cern.ch>
- Alessio Deiana <alessio.deiana@cern.ch>
- Anna Afshar <anna.afsharghasemlouy@epfl.ch>
- Antonios Manaras <antonios.manaras@cern.ch>
- Benoit Thiell <benoit.thiell@cern.ch>
- Carmen Alvarez Perez <carmen.alvarez.perez@cern.ch>
- Christopher Dickinson <christopher.dickinson@cern.ch>
- Cristian Bacchi <cristian.bacchi@gmail.com>
- Diane Berkovits <diane.berkovits@cern.ch>
- Eamonn Maguire <eamonnmag@gmail.com>
- Eirini Psallida <eirini.psallida@cern.ch>
- Esteban J. G. Gabancho <esteban.jose.garcia.gabancho@cern.ch>
- Ferran Jorba <Ferran.Jorba@uab.cat>
- Frederic Gobry <frederic.gobry@epfl.ch>
- Giovanni Di Milia <gdimilia@cfa.harvard.edu>
- Gregory Favre <gregory.favre@cern.ch>
- Grzegorz Szpura <grzegorz.szpura@cern.ch>
- Guillaume Lastecoueres <PX9e@gmx.fr>
- Henning Weiler <henning.weiler@cern.ch>
- Jaime García <jaime.garcia.llopis@cern.ch>
- Jan Aage Lavik <jan.age.lavik@cern.ch>
- Jan Iwaszkiewicz <jan.iwaszkiewicz@cern.ch>
- Javier Martin Montull <javier.martin.montull@cern.ch>
- Jerome Caffaro <jerome.caffaro@cern.ch>
- Jiri Kuncar <jiri.kuncar@cern.ch>
- João Batista <jnfbatista@gmail.com>
- Joaquim Rodrigues Silvestre <joaquim.rodrigues.silvestre@cern.ch>
- Joe Blaylock <jrbl@slac.stanford.edu>
- Kamil Neczaj <kamil.neczaj@cern.ch>
- Krzysztof Lis <krzysztof.lis@cern.ch>
- Kyriakos Liakopoulos <kyriakos.liakopoulos@cern.ch>
- Lars Christian Raae <lars.christian.raae@cern.ch>
- Lars Holm Nielsen <lars.holm.nielsen@cern.ch>
- Leonardo Rossi <leonardo.r@cern.ch>
- Ludmila Marian <ludmila.marian@gmail.com>
- Marko Niinimaki <manzikki@gmail.com>
- Martin Vesely <martin.vesely@cern.ch>
- Miguel Martín <miguelm@unizar.es>
- Mike Sullivan <sul@slac.stanford.edu>
- Nikolaos Kasioumis <nikolaos.kasioumis@cern.ch>
- Olivier Serres <olivier.serres@gmail.com>
- Pablo Vázquez Caderno <pcaderno@cern.ch>
- Patrick Glauner <patrick.oliver.glauner@cern.ch>
- Paulo Cabral <paulo.cabral@cern.ch>
- Pedro Gaudêncio <pedro.gaudencio@cern.ch>
- Peter Halliday <phalliday@cornell.edu>
- Piotr Praczyk <piotr.praczyk@gmail.com>
- Radoslav Ivanov <radoslav.ivanov@cern.ch>
- Raja Sripada <rsripada@cern.ch>
- Raquel Jimenez Encinar <raquel.jimenez.encinar@cern.ch>
- Roman Chyla <roman.chyla@cern.ch>
- Sami Hiltunen <sami.mikael.hiltunen@cern.ch>
- Samuele Carli <samuele.carli@cern.ch>
- Samuele Kaplun <samuele.kaplun@cern.ch>
- Theodoropoulos Theodoros <theod@lib.auth.gr>
- Tibor Simko <tibor.simko@cern.ch>
- Travis C. Brooks <travis@slac.stanford.edu>
- Trond Aksel Myklebust <trond.aksel.myklebust@cern.ch>
- Valkyrie Savage <vasavage@gmail.com>
- Wojciech Ziolek <wojciech.ziolek@cern.ch>
- Yoan Blanc <yoan.blanc@cern.ch>
